Registration | OiRA

Topics

# Registration

## Why do I have to register?

The first thing you will be asked to do when you begin your first risk assessment is to create an OiRA account - this is a simple and quick process.

Registering allows you to log in at any time to access your data, continue previous assessments or start new ones.

Registering means the OiRA system can save all your sessions, and your data will always be available.

Read our privacy policy and find out how we deal with your personal data.

## What is the difference between registering as a user and a doing a test session?

The test session allows interested parties to have a look at the tool before deciding to register. However, during a test session your data is not saved, and you will not be able to retrieve any information you entered at a later point. The test session does not allow you to print any of the reports, whereas registering your account allows you to fully document your risk assessment.

## Register for a new account

Is this your first visit? Follow these simple steps to get started:

1.) Click on ‘Register’ to view the registration form.

Registration form.

2.) Enter your e-mail address and choose a password (twice)

3.) Click on ‘Next’ to register your new account.

4.) Read and accept the privacy policy to continue

You will now be logged into the OiRA system.

## Logging in to an existing account

If you have registered previously, this is how to access your account:

1.) Visit the log-in form. A link to the log-in form will appear whenever you try to access OiRA, until you have logged in.

Login form.

2.) Fill in your e-mail address and your password.

3.) Sign in by clicking the button ‘Login’.

Once you are logged in, you will see the screen below. From here you can start a new risk assessment or return to risk assessments you have started previously.

The dashboard.

Start a new risk assessment by giving it a title (e.g. My-Company 2018-07-03) or access one of your previous risk assessments. All your risk assessments are saved for future reference unless you choose to delete them.

Scroll to top Load toolbar…
Back

## 1-registration.md

More…

- New risk assessment
- Show archived risk assessments
- All types of risk assessments Only regular risk assessments Only contractor risk assessments

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More